@@ -8,8 +8,6 @@ class BranchRestrictions(BitbucketCloudBase):
         super(BranchRestrictions, self).__init__(url, *args, **kwargs)
 
     def __get_object(self, data):
-        if "errors" in data:
-            return
         return BranchRestriction(data, **self._new_session_args)
 
     def create(
@@ -42,6 +40,8 @@ class BranchRestrictions(BitbucketCloudBase):
                              Minimal: {"owner": {"username": "<teamname>"}, "slug": "<groupslug>"}
 
         :return: The created BranchRestriction object
+
+        API docs: https://developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/branch-restrictions#post
         """
         if branch_match_kind == "branching_model":
             branch_pattern = ""
@@ -78,6 +78,8 @@ class BranchRestrictions(BitbucketCloudBase):
                              See https://developer.atlassian.com/bitbucket/api/2/reference/meta/filtering for details.
 
         :return: A generator for the BranchRestriction objects
+
+        API docs: https://developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/branch-restrictions#get
         """
         params = {}
         if kind is not None:
@@ -100,6 +102,8 @@ class BranchRestrictions(BitbucketCloudBase):
         :param id: string: The requested issue ID
 
         :return: The requested BranchRestriction objects
+
+        API docs: https://developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/branch-restrictions/%7Bid%7D#get
         """
         return self.__get_object(super(BranchRestrictions, self).get(id))
 
@@ -108,43 +112,64 @@ class BranchRestriction(BitbucketCloudBase):
     def __init__(self, data, *args, **kwargs):
         super(BranchRestriction, self).__init__(None, *args, data=data, expected_type="branchrestriction", **kwargs)
 
+    def update(self, **kwargs):
+        """
+        Update the branch restriction properties. Fields not present in the request body are ignored.
+
+        :param kwargs: dict: The data to update.
+
+        :return: The updated branch restriction
+
+        API docs: https://developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/branch-restrictions/%7Bid%7D#put
+        """
+        return self._update_data(self.put(None, data=kwargs))
+
+    def delete(self):
+        """
+        Delete the branch restriction.
+
+        :return: The response on success
+
+        API docs: https://developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/branch-restrictions/%7Bid%7D#delete
+        """
+        return super(BranchRestriction, self).delete(None)
+
     @property
     def id(self):
+        """ The branch restriction id """
         return str(self.get_data("id"))
 
     @property
     def kind(self):
+        """ The branch restriction kind """
         return self.get_data("kind")
 
     @property
     def branch_match_kindstring(self):
+        """ The branch restriction match kindstring """
         return self.get_data("branch_match_kindstring")
 
     @property
     def branch_typestring(self):
+        """ The branch restriction typestring """
         return self.get_data("branch_typestring")
 
     @property
     def pattern(self):
+        """ The branch restriction pattern """
         return self.get_data("pattern")
 
     @property
     def users(self):
+        """ The branch restriction users """
         return self.get_data("users")
 
     @property
     def groups(self):
+        """ The branch restriction groups """
         return self.get_data("groups")
 
     @property
     def value(self):
+        """ The branch restriction value """
         return self.get_data("value")
-
-    def delete(self):
-        """
-        Deletes the branch restriction
-        """
-        data = super(BranchRestriction, self).delete(None)
-        if data is None or "errors" in data:
-            return
-        return BranchRestriction(data, **self._new_session_args)
